import { CustomError } from '@abearxiong/router';
import { AppModel, AppListModel } from './module/index.ts';
import { app } from '@/app.ts';

app
  .route({
    path: 'user-app',
    key: 'list',
    middleware: ['auth'],
  })
  .define(async (ctx) => {
    const tokenUser = ctx.state.tokenUser;
    const list = await AppModel.findAll({
      order: [['updatedAt', 'DESC']],
      where: {
        uid: tokenUser.id,
      },
    });
    ctx.body = list;
    return ctx;
  })
  .addTo(app);

app
  .route({
    path: 'user-app',
    key: 'get',
    middleware: ['auth'],
  })
  .define(async (ctx) => {
    const id = ctx.query.id;
    if (!id) {
      throw new CustomError('id is required');
    }
    const am = await AppModel.findByPk(id);
    if (!am) {
      throw new CustomError('app not found');
    }
    ctx.body = am;
    return ctx;
  })
  .addTo(app);

app
  .route({
    path: 'user-app',
    key: 'update',
    middleware: ['auth'],
  })
  .define(async (ctx) => {
    const { data, id, ...rest } = ctx.query.data;
    if (id) {
      const app = await AppModel.findByPk(id);
      if (app) {
        const newData = { ...app.data, ...data };
        const newApp = await app.update({ data: newData, ...rest });
        ctx.body = newApp;
      } else {
        throw new CustomError('app not found');
      }
      return;
    }
    const tokenUser = ctx.state.tokenUser;
    const app = await AppModel.create({ data, ...rest, uid: tokenUser.id });
    ctx.body = app;
    return ctx;
  })
  .addTo(app);

app
  .route({
    path: 'user-app',
    key: 'delete',
    middleware: ['auth'],
  })
  .define(async (ctx) => {
    const id = ctx.query.id;
    if (!id) {
      throw new CustomError('id is required');
    }
    const am = await AppModel.findByPk(id);
    if (!am) {
      throw new CustomError('app not found');
    }
    await am.destroy();
    return ctx;
  })
  .addTo(app);
